## Info

- program: licensecheck
- version: dev
- license: MIT LICENSE

## Project License

MIT LICENSE

## Packages

Find a list of packages below

|Compatible|Package|
|:--|:--|
|✔|example0|
|✖|example1|

### example0-1.0.0

- HomePage: https://example.com
- Author: example_author
- License: MIT
- Compatible: True
- Size: 10

### example1-UNKNOWN

- HomePage: https://example.com
- Author: example_author
- License: GPL3
- Compatible: False
- Size: 10
